# PEQNP [![Downloads](https://pepy.tech/badge/peqnp)](https://pepy.tech/project/peqnp)

<a href="https://www.peqnp.com"><img border="0" alt="PEQNP" src="https://raw.githubusercontent.com/maxtuno/PEQNP/master/logo.png" width="640" height="400">

## Mathematical Solver

The PEQNP System its an automatic CNF encoder integrated with Python.

# [Try PEQNP on Google Colab ](https://colab.research.google.com/github/maxtuno/PEQNP/blob/master/docs/PEQNP.ipynb)

#### Thanks to JetBrains for support this project!

<a href="https://www.jetbrains.com/?from=PEQNP"><img border="0" alt="JetBrains support this project" src="https://raw.githubusercontent.com/maxtuno/PEQNP/master/jetbrains.png" width="100" height="100">

# Installation
```python
pip install PEQNP
# --install-option=no-solver to use with CNF or SDK submodule
```

# SLIME 4 SAT Solver 

[Sat Competition 2020, 3rd place on Cloud Tack](https://satcompetition.github.io/2020/results.html)

# SLIME 5 SAT Solver

[Currently the best sat solver, several light years around](https://maxtuno.github.io/slime-sat-solver/)

